@@ -8,6 +8,7 @@ import functools
 import os
 import threading
 import time
+import random
 
 
 class TransportNotReadyError(Exception):
@@ -214,6 +215,7 @@ class TCPTransport(Transport):
         self._bindAttempts = 0
         self._bindOverEvent = threading.Event() # gets triggered either when the server has either been bound correctly or when the number of bind attempts exceeds the config value maxBindRetries
         self._ready = False
+        self._send_random_sleep_duration = 0
 
         self._syncObj.addOnTickCallback(self._onTick)
 
@@ -517,10 +519,13 @@ class TCPTransport(Transport):
         self._nodes.add(node)
         self._nodeAddrToNode[node.address] = node
         if self._shouldConnect(node):
-            conn = TcpConnection(poller = self._syncObj._poller,
-                                 timeout = self._syncObj.conf.connectionTimeout,
-                                 sendBufferSize = self._syncObj.conf.sendBufferSize,
-                                 recvBufferSize = self._syncObj.conf.recvBufferSize)
+            conn = TcpConnection(
+                poller = self._syncObj._poller,
+                timeout = self._syncObj.conf.connectionTimeout,
+                sendBufferSize = self._syncObj.conf.sendBufferSize,
+                recvBufferSize = self._syncObj.conf.recvBufferSize,
+                keepalive = self._syncObj.conf.tcp_keepalive,
+            )
             conn.encryptor = self._syncObj.encryptor
             conn.setOnConnectedCallback(functools.partial(self._onOutgoingConnected, conn))
             conn.setOnMessageReceivedCallback(functools.partial(self._onMessageReceived, node))
@@ -562,6 +567,8 @@ class TCPTransport(Transport):
 
         if node not in self._connections or self._connections[node].state != CONNECTION_STATE.CONNECTED:
             return False
+        if self._send_random_sleep_duration:
+            time.sleep(random.random() * self._send_random_sleep_duration)
         self._connections[node].send(message)
         if self._connections[node].state != CONNECTION_STATE.CONNECTED:
             return False
